package com.jiuqi.util;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintStream;
import java.io.StringReader;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.List;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/JqLib.class */
public final class JqLib {
    public static final String EMPTY_STRING = "";
    public static final String SQL_FALSE = "0";
    public static final String SQL_TRUE = "1";
    public static final char[] HEX_CHARS = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
    public static final char[] BASE64_CHARS = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '+', '/', '='};
    private static final int[] DAYS_IN_MONTH = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
    public static PrintStream testLogger = null;

    public static boolean isEmpty(String value) {
        return value == null || value.equals("");
    }

    public static boolean isBoolTrue(String sqlValue) {
        if (sqlValue != null) {
            return sqlValue.equals(SQL_TRUE) || sqlValue.equalsIgnoreCase("T") || sqlValue.equalsIgnoreCase("TRUE");
        }
        return false;
    }

    public static boolean isSymbol(String s) {
        if (s == null || s.length() == 0) {
            return false;
        }
        for (int i = 0; i < s.length(); i++) {
            if (!Character.isLetterOrDigit(s.charAt(i)) && '_' != s.charAt(i)) {
                return false;
            }
        }
        return true;
    }

    public static boolean isIdentifier(String s) {
        if (s == null || s.length() == 0) {
            return false;
        }
        for (int i = 0; i < s.length(); i++) {
            if (!Character.isLetterOrDigit(s.charAt(i)) && '_' != s.charAt(i)) {
                return false;
            }
        }
        return Character.isLetter(s.charAt(0)) || '_' == s.charAt(0);
    }

    public static boolean isNumberString(String s) {
        if (s == null || s.length() == 0) {
            return false;
        }
        for (int i = 0; i < s.length(); i++) {
            if (!Character.isDigit(s.charAt(i))) {
                return false;
            }
        }
        return true;
    }

    public static boolean hasSpaceChar(String s) {
        for (int i = 0; i < s.length(); i++) {
            if (Character.isSpaceChar(s.charAt(i))) {
                return true;
            }
        }
        return false;
    }

    public static String convInput(String input) {
        try {
            return new String(input.getBytes("ISO8859_1"));
        } catch (Exception unused) {
            return input;
        }
    }

    public static String quoteString(String s) {
        return String.valueOf('\"') + s + '\"';
    }

    public static String quoteStringSingle(String s) {
        return "'" + s + "'";
    }

    public static String toFixedString(long iv, int width) {
        NumberFormat fmt = NumberFormatManager.createIntegerFormat(width);
        return fmt.format(iv);
    }

    public static String toFixedString(long iv, boolean seperator) {
        NumberFormat fmt = NumberFormatManager.createNumberFormat(0, seperator);
        return fmt.format(iv);
    }

    public static String replaceString(String s, String sub, String rep) {
        int pos;
        if (rep == null) {
            rep = "";
        }
        StringBuffer sb = new StringBuffer();
        int fromIndex = 0;
        do {
            pos = s.indexOf(sub, fromIndex);
            if (pos >= 0) {
                if (pos > fromIndex) {
                    sb.append(s.substring(fromIndex, pos));
                }
                sb.append(rep);
                fromIndex = pos + sub.length();
            }
        } while (pos >= 0);
        if (fromIndex < s.length()) {
            sb.append(s.substring(fromIndex, s.length()));
        }
        return sb.toString();
    }

    public static String toFixedString(double value, boolean seperator) {
        NumberFormat fmt = new DecimalFormat();
        fmt.setGroupingUsed(seperator);
        return fmt.format(value);
    }

    public static String strExclude(String str, char ch) {
        if (str == null) {
            return null;
        }
        char[] chars = new char[str.length()];
        int index = 0;
        for (int i = 0; i < str.length(); i++) {
            char c = str.charAt(i);
            if (c != ch) {
                int i2 = index;
                index++;
                chars[i2] = c;
            }
        }
        return new String(chars, 0, index);
    }

    public static boolean charIsInCharSet(char value, char[] chrSet) {
        for (char c : chrSet) {
            if (value == c) {
                return true;
            }
        }
        return false;
    }

    public static String strExclude(String str, char[] chs) {
        if (str == null) {
            return null;
        }
        if (chs == null) {
            return str;
        }
        char[] chars = new char[str.length()];
        int index = 0;
        for (int i = 0; i < str.length(); i++) {
            char c = str.charAt(i);
            if (!charIsInCharSet(c, chs)) {
                int i2 = index;
                index++;
                chars[i2] = c;
            }
        }
        return new String(chars, 0, index);
    }

    public static String trimEx(String src) {
        StringBuffer ret = new StringBuffer(src);
        int size = src.length();
        if (size == 0) {
            return "";
        }
        for (int i = ret.length() - 1; i >= 0; i--) {
            if (ret.charAt(i) == '\n' || ret.charAt(i) == '\r') {
                ret.deleteCharAt(i);
            }
        }
        return trim(ret.toString());
    }

    public static String trim(String str) {
        if (str == null) {
            return null;
        }
        int s1 = -1;
        for (int i = 0; i < str.length() && (str.charAt(i) == ' ' || str.charAt(i) == 12288); i++) {
            s1 = i;
        }
        int s12 = s1 + 1;
        int s2 = str.length();
        for (int i2 = s2 - 1; i2 >= s12 && (str.charAt(i2) == ' ' || str.charAt(i2) == 12288); i2--) {
            s2 = i2;
        }
        if (s12 == 0 && s2 == str.length()) {
            return str;
        }
        if (s12 >= s2) {
            return "";
        }
        return str.substring(s12, s2);
    }

    public static String trimLeft(String str) {
        if (str == null) {
            return null;
        }
        int s1 = 0;
        for (int i = 0; i < str.length() && str.charAt(i) == ' '; i++) {
            s1 = i;
        }
        int s2 = str.length();
        return s1 == 0 ? str : s1 >= s2 ? "" : str.substring(s1, str.length());
    }

    public static String trimRight(String str) {
        if (str == null) {
            return null;
        }
        int s2 = str.length();
        for (int i = s2 - 1; i >= 0 && str.charAt(i) == ' '; i--) {
            s2 = i;
        }
        return s2 == str.length() ? str : s2 <= 0 ? "" : str.substring(0, s2);
    }

    public static int compareString(String s1, String s2) {
        if (s1 == s2) {
            return 0;
        }
        if (s1 == null) {
            return -1;
        }
        if (s2 == null) {
            return 1;
        }
        return s1.compareTo(s2);
    }

    public static int compareArray(int[] a1, int[] a2) {
        if (a1 == a2) {
            return 0;
        }
        if (a1 == null) {
            return -1;
        }
        if (a2 == null) {
            return 1;
        }
        int result = a1.length - a2.length;
        if (result != 0) {
            return result;
        }
        for (int i = 0; i < a1.length; i++) {
            result = a1[i] - a2[i];
            if (result != 0) {
                return result;
            }
        }
        return result;
    }

    public static String getLine(String text, int linenum) {
        if (text == null) {
            return "";
        }
        BufferedReader buffer = new BufferedReader(new StringReader(text));
        String line = null;
        while (true) {
            try {
                int i = linenum;
                linenum--;
                if (i >= 0) {
                    line = buffer.readLine();
                } else {
                    return line;
                }
            } catch (IOException unused) {
                return text;
            }
        }
    }

    public static String encodePassword(String password, int maxlength) {
        int s1 = 97;
        int s2 = 76;
        int len = password == null ? 0 : password.length();
        if (len > maxlength) {
            len = maxlength;
        }
        StringBuffer pw = new StringBuffer(2 * maxlength);
        int i = 0;
        while (i < maxlength) {
            int i2 = s1;
            s1++;
            int i3 = s2;
            int s22 = s2 + 1;
            int ch = (i2 + ((i >= len || password == null) ? 0 : password.charAt(i))) ^ i3;
            int ch1 = (ch / 26) + 73;
            int ch2 = (ch % 26) + 65;
            s2 = (i & 1) == 1 ? s22 + (ch1 & 15) : s22 - (ch1 & 15);
            pw.append((char) ch1);
            pw.append((char) ch2);
            i++;
        }
        return new String(pw);
    }

    public static String decodePassword(String password) {
        if (password == null) {
            return "";
        }
        int s1 = 97;
        int s2 = 76;
        int len = password.length() / 2;
        StringBuffer pw = new StringBuffer();
        for (int i = 0; i < len; i++) {
            int ch1 = password.charAt(2 * i);
            int ch2 = password.charAt((2 * i) + 1);
            int i2 = s2;
            int s22 = s2 + 1;
            int i3 = (((ch1 - 73) * 26) + (ch2 - 65)) ^ i2;
            int i4 = s1;
            s1++;
            int ch = i3 - i4;
            if (ch == 0) {
                break;
            }
            pw.append((char) ch);
            s2 = (i & 1) == 1 ? s22 + (ch1 & 15) : s22 - (ch1 & 15);
        }
        return new String(pw);
    }

    public static int[] stringToColRow(String str) {
        int[] pos = {0, 0};
        int i = 0;
        while (true) {
            if (i >= str.length()) {
                break;
            }
            char ch = str.charAt(i);
            if (ch >= 'A' && ch <= 'Z') {
                pos[0] = (((pos[0] * 26) + ((byte) ch)) - 65) + 1;
                i++;
            } else {
                try {
                    pos[1] = Integer.parseInt(str.substring(i));
                    break;
                } catch (NumberFormatException unused) {
                    pos[1] = 0;
                }
            }
        }
        if (pos[0] <= 0 || pos[1] <= 0) {
            return null;
        }
        return pos;
    }

    public static String colRowToString(int x, int y) {
        char[] chrArray = new char[64];
        int len = 0;
        while (x > 0) {
            char ch = (char) (((x % 26) + 65) - 1);
            x /= 26;
            if (ch < 'A') {
                ch = 'Z';
                x--;
            }
            chrArray[len] = ch;
            len++;
        }
        String colStr = "";
        for (int i = 0; i < len; i++) {
            colStr = String.valueOf(colStr) + chrArray[(len - i) - 1];
        }
        return String.valueOf(colStr) + Integer.toString(y);
    }

    public static String makeHexString(int iv) {
        char[] buf = new char[8];
        int charPos = 7;
        while (iv != 0) {
            int i = charPos;
            charPos--;
            buf[i] = HEX_CHARS[iv & 15];
            iv >>>= 4;
        }
        while (charPos >= 0) {
            int i2 = charPos;
            charPos--;
            buf[i2] = HEX_CHARS[0];
        }
        return new String(buf);
    }

    public static int parseHexValue(String hex) {
        return (int) Long.parseLong(hex, 16);
    }

    public static String bytesToHexString(byte[] data) {
        if (data == null) {
            return null;
        }
        StringBuffer result = new StringBuffer(data.length * 2);
        for (int i = 0; i < data.length; i++) {
            int b = data[i];
            if (b < 0) {
                b += 256;
            }
            if (b < 16) {
                result.append('0');
            }
            result.append(Integer.toHexString(b));
        }
        return result.toString().toUpperCase();
    }

    public static byte[] hexStringToBytes(String hexString) {
        if (hexString == null) {
            return null;
        }
        byte[] result = new byte[hexString.length() / 2];
        for (int i = 0; i < result.length; i++) {
            result[i] = Integer.decode("0x" + hexString.substring(2 * i, (2 * i) + 2)).byteValue();
        }
        return result;
    }

    public static void listRevert(List list) {
        int high = list.size() - 1;
        for (int i = 0; i < list.size() / 2; i++) {
            Object o = list.get(i);
            list.set(i, list.get(high - i));
            list.set(high - i, o);
        }
    }

    public static void listMove(List list, int index1, int index2) {
        if (index1 > index2) {
            Object t = list.get(index1);
            for (int i = index1; i > index2; i--) {
                list.set(i, list.get(i - 1));
            }
            list.set(index2, t);
            return;
        }
        if (index1 < index2) {
            Object t2 = list.get(index1);
            for (int i2 = index1; i2 < index2; i2++) {
                list.set(i2, list.get(i2 + 1));
            }
            list.set(index2, t2);
        }
    }

    public static int listFind(List items, Comparable item) {
        if (item == null) {
            if (items.size() > 0 && items.get(0) == null) {
                return 0;
            }
            return -1;
        }
        int sb = 0;
        int se = items.size() - 1;
        int flag = -1;
        while (true) {
            if (sb <= se) {
                int sp = (sb + se) >> 1;
                flag = item.compareTo(items.get(sp));
                if (flag <= 0) {
                    if (flag >= 0) {
                        sb = sp;
                        break;
                    }
                    se = sp - 1;
                } else {
                    sb = sp + 1;
                }
            } else {
                break;
            }
        }
        return flag == 0 ? sb : (-sb) - 1;
    }

    public static int listSortAdd(List items, Object item) {
        int index = listFind(items, (Comparable) item);
        if (index < 0) {
            index = (-index) - 1;
            items.add(index, item);
        }
        return index;
    }

    public static void listSort(List items) {
        if (items.size() > 1) {
            listQuickSort(items, 0, items.size() - 1);
        }
    }

    protected static void listQuickSort(List items, int left, int right) {
        int i;
        do {
            i = left;
            int j = right;
            Comparable item = (Comparable) items.get((left + right) >> 1);
            while (true) {
                if (item.compareTo(items.get(i)) <= 0) {
                    while (item.compareTo(items.get(j)) < 0) {
                        j--;
                    }
                    if (i <= j) {
                        Object o = items.get(i);
                        items.set(i, items.get(j));
                        items.set(j, o);
                        i++;
                        j--;
                    }
                    if (i > j) {
                        break;
                    }
                } else {
                    i++;
                }
            }
            if (left < j) {
                listQuickSort(items, left, j);
            }
            left = i;
        } while (i < right);
    }

    public static byte[] stringToBytes(String s) {
        if (s == null) {
            return null;
        }
        return s.getBytes();
    }

    public static String bytesToString(byte[] b) {
        if (b == null) {
            return null;
        }
        return new String(b);
    }

    public static boolean isLeapYear(int AYear) {
        if (AYear % 4 == 0) {
            return AYear % 100 != 0 || AYear % 400 == 0;
        }
        return false;
    }

    public static int daysPerMonth(int AYear, int AMonth) {
        return (AMonth == 2 && isLeapYear(AYear)) ? DAYS_IN_MONTH[AMonth] + 1 : DAYS_IN_MONTH[AMonth];
    }

    public static Calendar dayTermToDate(int AYear, int Term) {
        Calendar result = new GregorianCalendar();
        result.setTime(new Date(0L));
        result.set(AYear, 1, 1);
        if (Term <= 0) {
            Term = 1;
        }
        int I = 1;
        while (true) {
            if (I > 12) {
                break;
            }
            if (Term <= daysPerMonth(AYear, I)) {
                result.set(AYear, I, Term);
                break;
            }
            Term -= daysPerMonth(AYear, I);
            I++;
        }
        return result;
    }

    public static String getFileName(String name) {
        String returnStr = StringUtils.replace(name, "/", "");
        return StringUtils.replace(StringUtils.replace(StringUtils.replace(StringUtils.replace(StringUtils.replace(StringUtils.replace(StringUtils.replace(StringUtils.replace(returnStr, StringHelper.bias, ""), ":", ""), "\"", ""), ">", ""), "<", ""), "|", ""), StringHelper.interrogation, ""), "*", "");
    }

    public static String getChinaNumberTitle(int value) {
        switch (value) {
            case 0:
                return "零";
            case 1:
                return "一";
            case 2:
                return "二";
            case 3:
                return "三";
            case 4:
                return "四";
            case 5:
                return "五";
            case 6:
                return "六";
            case StatCell.STAT_MODE_LAST /* 7 */:
                return "七";
            case StatCell.STAT_MODE_LIST /* 8 */:
                return "八";
            case 9:
                return "九";
            case 10:
                return "十";
            default:
                return "一";
        }
    }

    public static void main(String[] args) {
        byte[] b = stringToBytes("孙建卫");
        System.out.println(b);
        String s = bytesToString(b);
        System.out.println(s);
        System.out.println();
    }
}
